
# Slot: phenotypic state


in experiments (e.g. gene expression) assaying diseased or unhealthy tissue, the phenotypic state can be put here, e.g. MONDO ID. For healthy tissues, use XXX.

URI: [biolink:phenotypic_state](https://w3id.org/biolink/vocab/phenotypic_state)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

 * [GeneExpressionMixin](GeneExpressionMixin.md)
 * [GeneToGeneCoexpressionAssociation](GeneToGeneCoexpressionAssociation.md)
 * [VariantToGeneExpressionAssociation](VariantToGeneExpressionAssociation.md)
